<?xml version="1.0"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
	<!-- This is version 0.2 of an IPTC NewsML stylesheet produced by David Allen, MD IPTC to covert NITF instances to NewsML. Copyright 2002 IPTC. -->
	<!-- It has been tested with the xt parser from James Clark and the Saxon parser from  Michael Kay-->
	<!-- It requires the Nitfv3.0.dtd -->
	<xsl:output method="xml" version="1.0" encoding="utf-8" doctype-public="urn:newsml:iptc.org:20001006:NewsMLv1.0" doctype-system="NewsMLv1.0.dtd"/>
	<xsl:variable name="defaultdomain" select="'iptc.org'"/>
	<xsl:variable name="defaultdate" select="'20020101T000000+0000'"/>
	<xsl:template match="nitf">
		<xsl:element name="NewsML" namespace="">
			<xsl:element name="Catalog" namespace="">
				<xsl:attribute name="Href">./catalog/iptc-nitf-catalog.xml</xsl:attribute>
			</xsl:element>
			<xsl:if test="head/pubdata or head/iim">
				<xsl:call-template name="pubtopic"/>
			</xsl:if>
			<xsl:if test="body/body.head/abstract or body/body.head/note">
				<xsl:call-template name="absnote"/>
			</xsl:if>
			<xsl:call-template name="envdat"/>
			<xsl:element name="NewsItem" namespace="">
				<xsl:call-template name="ident"/>
				<xsl:call-template name="newsman"/>
				<xsl:call-template name="mnewscomp"/>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="envdat">
		<xsl:element name="NewsEnvelope" namespace="">
			<xsl:if test="head/docdata/doc-id">
				<xsl:element name="TransmissionId" namespace="">
					<xsl:value-of select="head/docdata/doc-id/@regsrc"/>
					<xsl:value-of select="head/docdata/doc-id/@id-string"/>
					<xsl:if test="head/docdata/du-key/@key">
						<xsl:value-of select="head/docdata/du-key/@key"/>
					</xsl:if>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/docdata/del-list/from-src">
				<xsl:element name="SentFrom" namespace="">
					<xsl:value-of select="head/docdata/del-list/from-src"/>
				</xsl:element>
			</xsl:if>
			<xsl:element name="DateAndTime" namespace="">
				<xsl:choose>
					<xsl:when test="head/docdata/date.issue/@norm">
						<xsl:choose>
							<xsl:when test="(substring(head/docdata/date.issue/@norm,16,1)='+') or (substring(head/docdata/date.issue/@norm,16,1)='-') or (substring(head/docdata/date.issue/@norm,16,1)='Z') ">
								<xsl:value-of select="head/docdata/date.issue/@norm"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$defaultdate"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:if test="body/body.head/distributor">
				<xsl:element name="NewsService" namespace="">
					<xsl:attribute name="FormalName"><xsl:value-of select="body/body.head/distributor"/></xsl:attribute>
					<xsl:attribute name="Scheme">IptcProvider</xsl:attribute>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/docdata/du-key/@key">
				<xsl:element name="NewsProduct" namespace="">
					<xsl:attribute name="FormalName"><xsl:value-of select="head/docdata/du-key/@key"/></xsl:attribute>
					<xsl:attribute name="Scheme">MyProduct</xsl:attribute>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="ident">
		<xsl:element name="Identification" namespace="">
			<xsl:element name="NewsIdentifier" namespace="">
				<xsl:element name="ProviderId" namespace="">
					<xsl:value-of select="$defaultdomain"/>
				</xsl:element>
				<xsl:element name="DateId" namespace="">
					<xsl:choose>
						<xsl:when test="head/docdata/date.issue/@norm">
							<xsl:choose>
								<xsl:when test="(substring(head/docdata/date.issue/@norm,16,1)='+') or (substring(head/docdata/date.issue/@norm,16,1)='-') or (substring(head/docdata/date.issue/@norm,16,1)='Z')">
									<xsl:value-of select="head/docdata/date.issue/@norm"/>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$defaultdate"/>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="NewsItemId" namespace="">
					<xsl:choose>
						<xsl:when test="head/docdata/doc-id/@id-string">
							<xsl:value-of select="head/docdata/doc-id/@id-string"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>unknownid</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:element>
				<xsl:element name="RevisionId" namespace="">
					<xsl:attribute name="PreviousRevision"><xsl:text>0</xsl:text></xsl:attribute>
					<xsl:attribute name="Update">N</xsl:attribute>
					<xsl:text>1</xsl:text>
				</xsl:element>
				<xsl:element name="PublicIdentifier" namespace="">
					<xsl:text>urn:newsml:</xsl:text>
					<xsl:value-of select="$defaultdomain"/>
					<xsl:text>:</xsl:text>
					<xsl:choose>
						<xsl:when test="head/docdata/date.issue/@norm">
							<xsl:choose>
								<xsl:when test="(substring(head/docdata/date.issue/@norm,16,1)='+') or (substring(head/docdata/date.issue/@norm,16,1)='-') or (substring(head/docdata/date.issue/@norm,16,1)='Z') ">
									<xsl:value-of select="head/docdata/date.issue/@norm"/>
								</xsl:when>
							</xsl:choose>
						</xsl:when>
						<xsl:otherwise>
							<xsl:value-of select="$defaultdate"/>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>:</xsl:text>
					<xsl:choose>
						<xsl:when test="head/docdata/doc-id/@id-string">
							<xsl:value-of select="head/docdata/doc-id/@id-string"/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:text>unknownid</xsl:text>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:text>:1</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:if test="head/title">
				<xsl:element name="NameLabel" namespace="">
					<xsl:value-of select="head/title"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/docdata/date.issue/@norm">
				<xsl:element name="DateLabel" namespace="">
					<xsl:value-of select="head/docdata/date.issue/@norm"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="newsman">
		<xsl:element name="NewsManagement" namespace="">
			<xsl:element name="NewsItemType" namespace="">
				<xsl:attribute name="FormalName">News</xsl:attribute>
				<xsl:attribute name="Scheme">IptcNewsItemType</xsl:attribute>
			</xsl:element>
			<xsl:element name="FirstCreated" namespace="">
				<xsl:choose>
					<xsl:when test="head/docdata/date.issue/@norm">
						<xsl:choose>
							<xsl:when test="(substring(head/docdata/date.issue/@norm,16,1)='+') or (substring(head/docdata/date.issue/@norm,16,1)='-') or (substring(head/docdata/date.issue/@norm,16,1)='Z')">
								<xsl:value-of select="head/docdata/date.issue/@norm"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$defaultdate"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="ThisRevisionCreated" namespace="">
				<xsl:choose>
					<xsl:when test="head/docdata/date.release/@norm">
						<xsl:choose>
							<xsl:when test="(substring(head/docdata/date.release/@norm,16,1)='+') or (substring(head/docdata/date.release/@norm,16,1)='-') or (substring(head/docdata/date.release/@norm,16,1)='Z') ">
								<xsl:value-of select="head/docdata/date.release/@norm"/>
							</xsl:when>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$defaultdate"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
			<xsl:element name="Status" namespace="">
				<xsl:attribute name="FormalName">Usable</xsl:attribute>
				<xsl:attribute name="Scheme">IptcStatus</xsl:attribute>
			</xsl:element>
			<xsl:if test="head/docdata/urgency/@ed-urg">
				<xsl:element name="Urgency" namespace="">
					<xsl:attribute name="FormalName"><xsl:value-of select="head/docdata/urgency/@ed-urg"/></xsl:attribute>
					<xsl:attribute name="Scheme">IptcUrgency</xsl:attribute>
				</xsl:element>
			</xsl:if>
			<!--<xsl:if test="head/revision-history/@comment">
				<xsl:element name="RevisionHistory" namespace="">
					<xsl:value-of select="head/revision-history/@comment"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="docdata/ed-msg/@info">
				<xsl:element name="Instruction" namespace="">
					<xsl:value-of select="head/docdata/ed-msg/@info"/>
				</xsl:element>
			</xsl:if>-->
		</xsl:element>
	</xsl:template>
	<xsl:template name="mnewscomp">
		<xsl:element name="NewsComponent" namespace="">
			<xsl:element name="Role" namespace="">
				<xsl:attribute name="FormalName">Main</xsl:attribute>
				<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
			</xsl:element>
			<xsl:call-template name="bnewscomp"/>
			<xsl:if test="body/body.head/abstract">
				<xsl:call-template name="anewscomp"/>
			</xsl:if>
			<xsl:if test="body/body.head/note">
				<xsl:call-template name="nnewscomp"/>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="bnewscomp">
		<xsl:element name="NewsComponent" namespace="">
			<xsl:element name="Role" namespace="">
				<xsl:attribute name="FormalName">Story</xsl:attribute>
				<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
			</xsl:element>
			<xsl:element name="NewsLines" namespace="">
				<xsl:if test="body/body.head/hedline/hl1">
					<xsl:element name="HeadLine" namespace="">
						<xsl:value-of select="body/body.head/hedline/hl1"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/body.head/hedline/hl2">
					<xsl:element name="SubHeadLine" namespace="">
						<xsl:value-of select="body/body.head/hedline/hl2"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/body.head/byline">
					<xsl:element name="ByLine" namespace="">
						<xsl:value-of select="body/body.head/byline"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/body.head/dateline">
					<xsl:element name="DateLine" namespace="">
						<xsl:value-of select="body/body.head/dateline"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/body.content/bq/credit">
					<xsl:element name="CreditLine" namespace="">
						<xsl:value-of select="body/body.content/bq/credit"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.copyright/@holder">
					<xsl:element name="CopyrightLine" namespace="">
						<xsl:value-of select="head/docdata/doc.copyright/@holder"/>
						<xsl:if test="head/docdata/doc.copyright/@year">
						<xsl:text> </xsl:text>
							<xsl:value-of select="head/docdata/doc.copyright/@year"/>
						</xsl:if>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/head/docdata/doc.rights/@agent">
					<xsl:element name="RightsLine" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@agent"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="body/body.head/series/@series.name">
					<xsl:element name="SeriesLine" namespace="">
						<xsl:value-of select="body/body.head/series/@series.name"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/fixture/@fix-id">
					<xsl:element name="SlugLine" namespace="">
						<xsl:value-of select="head/docdata/fixture/@fix-id"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/key-list">
					<xsl:element name="KeywordLine" namespace="">
						<xsl:for-each select="head/docdata/key-list/keyword">
							<xsl:value-of select="@key"/>
							<xsl:text>, </xsl:text>
						</xsl:for-each>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/du-key">
					<xsl:element name="KeywordLine" namespace="">
						<xsl:if test="head/docdata/du-key/@generation">
							<xsl:value-of select="head/docdata/du-key/@generation"/>
						</xsl:if>
						<xsl:if test="head/docdata/du-key/@part">
							<xsl:text>, </xsl:text>
							<xsl:value-of select="head/docdata/du-key/@part"/>
						</xsl:if>
						<xsl:if test="head/docdata/du-key/@version">
							<xsl:text>, </xsl:text>
							<xsl:value-of select="head/docdata/du-key/@version"/>
						</xsl:if>
						<xsl:if test="head/docdata/du-key/@key">
							<xsl:text>, </xsl:text>
							<xsl:value-of select="head/docdata/du-key/@key"/>
						</xsl:if>
					</xsl:element>
				</xsl:if>
			</xsl:element>
			<xsl:call-template name="adminmeta"/>
			<xsl:call-template name="rightsmeta"/>
			<xsl:call-template name="descmeta"/>
			<xsl:call-template name="pubmeta"/>
			<xsl:call-template name="iimmeta"/>
			<xsl:call-template name="contents"/>
		</xsl:element>
	</xsl:template>
	<xsl:template name="anewscomp">
		<xsl:element name="NewsComponent" namespace="">
			<xsl:element name="Role" namespace="">
				<xsl:attribute name="FormalName">Abstract</xsl:attribute>
				<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
			</xsl:element>
			<xsl:element name="ContentItem" namespace="">
				<xsl:element name="DataContent" namespace="">
					<xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
					<!--<xsl:element name="nitf" namespace="urn:nitf:iptc.org:20010419:NITF">
<xsl:apply-templates mode="copynitf"/>
</xsl:element>-->
					<xsl:copy-of select="body/body.head/abstract"/>
					<xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="nnewscomp">
		<xsl:element name="NewsComponent" namespace="">
			<xsl:element name="Role" namespace="">
				<xsl:attribute name="FormalName">Note</xsl:attribute>
				<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
			</xsl:element>
			<xsl:element name="ContentItem" namespace="">
				<xsl:element name="DataContent" namespace="">
					<xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
					<!--<xsl:element name="nitf" namespace="urn:nitf:iptc.org:20010419:NITF">
<xsl:apply-templates mode="copynitf"/>
</xsl:element>-->
					<xsl:copy-of select="body/body.head/note"/>
					<xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="adminmeta">
		<xsl:element name="AdministrativeMetadata" namespace="">
			<xsl:if test="body/body.content/media/media-reference/@source">
				<xsl:element name="FileName" namespace="">
					<xsl:value-of select="body/body.content/media/media-reference/@source"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="body/body.head/distributor">
				<xsl:element name="Provider" namespace="">
					<xsl:element name="Party" namespace="">
						<xsl:attribute name="FormalName"><xsl:value-of select="body/body.head/distributor"/></xsl:attribute>
						<xsl:attribute name="Scheme">IptcProvider</xsl:attribute>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/revision-history/@name">
				<xsl:element name="Creator" namespace="">
					<xsl:element name="Party" namespace="">
						<xsl:attribute name="FormalName"><xsl:value-of select="head/revision-history/@name"/></xsl:attribute>
						<xsl:attribute name="Scheme">IptcProvider</xsl:attribute>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			<xsl:if test="body/body.head/distributor">
				<xsl:element name="Source" namespace="">
					<xsl:element name="Party" namespace="">
						<xsl:attribute name="FormalName"><xsl:value-of select="body/body.head/distributor"/></xsl:attribute>
						<xsl:attribute name="Scheme">IptcProvider</xsl:attribute>
					</xsl:element>
				</xsl:element>
			</xsl:if>
			<xsl:if test="body/body.head/distributor">
				<xsl:element name="Contributor" namespace="">
					<xsl:element name="Party" namespace="">
						<xsl:attribute name="FormalName"><xsl:value-of select="body/body.head/distributor"/></xsl:attribute>
						<xsl:attribute name="Scheme">IptcProvider</xsl:attribute>
					</xsl:element>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="rightsmeta">
		<xsl:element name="RightsMetadata" namespace="">
			<xsl:if test="head/docdata/doc.copyright/@holder">
				<xsl:element name="Copyright" namespace="">
					<xsl:element name="CopyrightHolder" namespace="">
						<xsl:value-of select="head/docdata/doc.copyright/@holder"/>
					</xsl:element>
					<xsl:if test="head/docdata/doc.copyright/@year">
						<xsl:element name="CopyrightDate" namespace="">
							<xsl:value-of select="head/docdata/doc.copyright/@year"/>
						</xsl:element>
					</xsl:if>
				</xsl:element>
			</xsl:if>
			<xsl:element name="UsageRights" namespace="">
				<xsl:if test="head/docdata/doc.rights/@type">
					<xsl:element name="UsageType" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@type"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.copyright/@geography">
					<xsl:element name="Geography" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@geography"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.rights/@owner">
					<xsl:element name="RightsHolder" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@owner"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.copyright/@limitations">
					<xsl:element name="Limitations" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@limitations"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.rights/@startdate">
					<xsl:element name="StartDate" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@startdate"/>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/docdata/doc.copyright/@enddate">
					<xsl:element name="EndDate" namespace="">
						<xsl:value-of select="head/docdata/doc.rights/@enddate"/>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="descmeta">
		<xsl:element name="DescriptiveMetadata" namespace="">
			<xsl:if test="body/body.content/block/@lang">
				<xsl:element name="Language" namespace="">
					<xsl:value-of select="body/body.content/block/@lang"/>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/tobject/tobject.subject/@tobject.subject.refnum">
				<xsl:element name="SubjectCode" namespace="">
					<xsl:for-each select="head/tobject/tobject.subject">
						<xsl:choose>
							<xsl:when test="substring(@tobject.subject.refnum,3,6)='000000'">
								<xsl:element name="Subject" namespace="">
									<xsl:attribute name="FormalName"><xsl:value-of select="@tobject.subject.refnum"/></xsl:attribute>
									<xsl:attribute name="Scheme">IptcSubjectCodes</xsl:attribute>
								</xsl:element>
							</xsl:when>
							<xsl:when test="substring(@tobject.subject.refnum,3,3)!='000' and substring(@tobject.subject.refnum,6,3)='000'">
								<xsl:element name="SubjectMatter" namespace="">
									<xsl:attribute name="FormalName"><xsl:value-of select="@tobject.subject.refnum"/></xsl:attribute>
									<xsl:attribute name="Scheme">IptcSubjectCodes</xsl:attribute>
								</xsl:element>
							</xsl:when>
							<xsl:when test="substring(@tobject.subject.refnum,3,3)!='000' and substring(@tobject.subject.refnum,6,3)!='000' ">
								<xsl:element name="SubjectDetail" namespace="">
									<xsl:attribute name="FormalName"><xsl:value-of select="@tobject.subject.refnum"/></xsl:attribute>
									<xsl:attribute name="Scheme">IptcSubjectCodes</xsl:attribute>
								</xsl:element>
							</xsl:when>
							<xsl:when test="substring(@tobject.subject.refnum,3,3)='000' and substring(@tobject.subject.refnum,6,3)!='000' ">
								<xsl:element name="SubjectQualifier" namespace="">
									<xsl:attribute name="FormalName"><xsl:value-of select="@tobject.subject.refnum"/></xsl:attribute>
									<xsl:attribute name="Scheme">IptcSubjectCodes</xsl:attribute>
								</xsl:element>
							</xsl:when>
						</xsl:choose>
					</xsl:for-each>
				</xsl:element>
			</xsl:if>
			<xsl:if test="head/doc.data/doc-scope/@scope">
				<xsl:element name="OfInterestTo" namespace="">
					<xsl:value-of select="body/head/doc-scope/@scope"/>
				</xsl:element>
			</xsl:if>
		</xsl:element>
	</xsl:template>
	<xsl:template name="contents">
		<xsl:element name="ContentItem" namespace="">
			<xsl:element name="DataContent" namespace="">
				<xsl:text disable-output-escaping="yes">&lt;![CDATA[</xsl:text>
				<!--<xsl:element name="nitf" namespace="">
<xsl:apply-templates mode="copynitf"/>
</xsl:element>-->
				<xsl:copy-of select="body/body.content"/>
				<xsl:text disable-output-escaping="yes">]]&gt;</xsl:text>
			</xsl:element>
		</xsl:element>
	</xsl:template>
	<xsl:template name="pubtopic">
		<xsl:element name="TopicSet" namespace="">
			<xsl:attribute name="Duid"><xsl:text>newmltopictypes</xsl:text></xsl:attribute>
			<xsl:attribute name="FormalName"><xsl:text>TopicType</xsl:text></xsl:attribute>
			<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
			<xsl:element name="TopicSetRef" namespace="">
				<xsl:attribute name="TopicSet"><xsl:text>urn:newsml:iptc.org:20001006:topicset.iptc-topictype:1</xsl:text></xsl:attribute>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubmeta</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>TopicType</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					<xsl:text>MetadataName</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Naming of additional Metadata types</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubmetapropn</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>TopicType</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					<xsl:text>PubPropertyName</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Naming of Publishing Metadata Properties</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubiimpropn</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>TopicType</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					<xsl:text>IIMPropertyName</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Naming of IIM  Metadata Properties</xsl:text>
				</xsl:element>
			</xsl:element>

			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubmetapropv</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>TopicType</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					<xsl:text>PubPropertyValue</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Naming of Publishing Metadata Property values</xsl:text>
				</xsl:element>
			</xsl:element>
		</xsl:element>
		<xsl:element name="TopicSet" namespace="">
			<xsl:attribute name="Duid"><xsl:text>pubmetadata</xsl:text></xsl:attribute>
			<xsl:attribute name="FormalName"><xsl:text>MetadataName</xsl:text></xsl:attribute>
			<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubmeta1</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>MetadataName</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">NitfMeta</xsl:attribute>
					<xsl:text>PublishingMetadata</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Publishing metadata drawn fron NITF</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>iimmeta</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>MetadataName</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">NitfMeta</xsl:attribute>
					<xsl:text>IIMMetadata</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>IIM metadata drawn from NITF</xsl:text>
				</xsl:element>
			</xsl:element>
		</xsl:element>
		<xsl:if test="head/iim">
			<xsl:element name="TopicSet" namespace="">
				<xsl:attribute name="Duid"><xsl:text>iimprops</xsl:text></xsl:attribute>
				<xsl:attribute name="FormalName"><xsl:text>IIMPropertyName</xsl:text></xsl:attribute>
				<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>iimprop1</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>IIMPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">IIMProperty</xsl:attribute>
						<xsl:text>num</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>IIM dataset number in form xxx:yyy</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>iimprop2</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>IIMPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">IIMProperty</xsl:attribute>
						<xsl:text>value</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>IIM dataset content</xsl:text>
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:if>
		<xsl:if test="head/pubdata">
			<xsl:element name="TopicSet" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubprops</xsl:text></xsl:attribute>
				<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
				<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop1</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Type</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Transport medium, such as print, streaming video or broadcast</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop2</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>ItemLength</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>length of item (in units of measure)</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop3</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>UnitOfMeasure</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measure associated with length of item</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop4</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>DatePublication</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Date time news published</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop5</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Name</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Title of Publication</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop6</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Issn</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>The International Standard Serial Number</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop7</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Volume</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Volume of publication in which information appeared</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop8</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Number</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Publication number</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop9</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>Issue</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Name of the issue</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop10</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>EditionName</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Name of the edition</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop11</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>EditionArea</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Area/zone where news object was distributed</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop12</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>PositionSection</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Named section where news object appeared</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop13</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>PositionSequence</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Where news object appeared among a list of items (often page number)</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubprop14</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyName</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:text>ExRef</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>External refrence to rendering of news object (URN)</xsl:text>
					</xsl:element>
				</xsl:element>
			</xsl:element>
			<xsl:element name="TopicSet" namespace="">
				<xsl:attribute name="Duid"><xsl:text>pubvals</xsl:text></xsl:attribute>
				<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
				<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval1</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>print</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Print medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval2</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>audio</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Audio medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval3</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>video</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Video medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval4</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>web</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Web medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval5</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>appliance</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Appliance medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval6</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">PubTypeVal</xsl:attribute>
						<xsl:text>other</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Other medium</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval7</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>word</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of word</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval8</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>character</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of character</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval9</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>byte</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of byte</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval10</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>inch</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of inch</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval11</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>pica</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of pica</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval12</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>cm</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of centimetre</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval13</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>hour</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of hour</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval14</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>minute</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of minute</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval15</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>second</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit of second</xsl:text>
					</xsl:element>
				</xsl:element>
				<xsl:element name="Topic" namespace="">
					<xsl:attribute name="Duid"><xsl:text>pubval16</xsl:text></xsl:attribute>
					<xsl:element name="TopicType" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PubPropertyValue</xsl:text></xsl:attribute>
						<xsl:attribute name="Scheme">ExtraTopicType</xsl:attribute>
					</xsl:element>
					<xsl:element name="FormalName" namespace="">
						<xsl:attribute name="Scheme">LOMVal</xsl:attribute>
						<xsl:text>other</xsl:text>
					</xsl:element>
					<xsl:element name="Description" namespace="">
						<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
						<xsl:text>Measurement unit unspecified</xsl:text>
					</xsl:element>
				</xsl:element>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template name="pubmeta">
		<!--metadata follows-->
		<xsl:if test="head/pubdata">
			<xsl:element name="Metadata" namespace="">
				<xsl:attribute name="Duid"><xsl:text>mext1</xsl:text></xsl:attribute>
				<xsl:element name="MetadataType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>PublishingMetadata</xsl:text></xsl:attribute>
					<xsl:attribute name="Vocabulary">#pubmetadata</xsl:attribute>
					<xsl:attribute name="Scheme">NitfMeta</xsl:attribute>
				</xsl:element>
				<xsl:if test="head/pubdata/@type">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Type</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@type"/></xsl:attribute>
						<xsl:attribute name="AllowedValues">#pubvals</xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@item-length">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>ItemLength</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@item-length"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@unit-of-measure">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>UnitOfMeasure</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@unit-of-measure"/></xsl:attribute>
						<xsl:attribute name="AllowedValues">#pubvals</xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@date.publication">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>DatePublication</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@date.publication"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@name">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Name</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@name"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@issn">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Issn</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@issn"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@volume">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Volume</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@volume"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@number">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Number</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@number"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@issue">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>Issue</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@issue"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@edition.name">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>EditionName</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@edition.name"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@edition.area">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>EditionArea</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@edition.area"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@position.section">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PositionSection</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@position.section"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@position.sequence">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>PositionSequence</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@position.sequence"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
				<xsl:if test="head/pubdata/@ex-ref">
					<xsl:element name="Property" namespace="">
						<xsl:attribute name="FormalName"><xsl:text>ExRef</xsl:text></xsl:attribute>
						<xsl:attribute name="Vocabulary">#pubprops</xsl:attribute>
						<xsl:attribute name="Scheme">PubProperty</xsl:attribute>
						<xsl:attribute name="Value"><xsl:value-of select="head/pubdata/@ex-ref"/></xsl:attribute>
					</xsl:element>
				</xsl:if>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template name="iimmeta">
		<!--metadata follows-->
		<xsl:if test="head/iim">
			<xsl:element name="Metadata" namespace="">
				<xsl:attribute name="Duid"><xsl:text>mext2</xsl:text></xsl:attribute>
				<xsl:element name="MetadataType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>IIMMetadata</xsl:text></xsl:attribute>
					<xsl:attribute name="Vocabulary">#pubmetadata</xsl:attribute>
					<xsl:attribute name="Scheme">NitfMeta</xsl:attribute>
				</xsl:element>
				<xsl:for-each select="head/iim/ds">
					<xsl:if test="@num">
						<xsl:element name="Property" namespace="">
							<xsl:attribute name="FormalName"><xsl:text>num</xsl:text></xsl:attribute>
							<xsl:attribute name="Vocabulary">#iimprops</xsl:attribute>
							<xsl:attribute name="Scheme">IIMProperty</xsl:attribute>
							<xsl:attribute name="Value"><xsl:value-of select="@num"/></xsl:attribute>
						</xsl:element>
					</xsl:if>
					<xsl:if test="@value">
						<xsl:element name="Property" namespace="">
							<xsl:attribute name="FormalName"><xsl:text>value</xsl:text></xsl:attribute>
							<xsl:attribute name="Vocabulary">#iimprops</xsl:attribute>
							<xsl:attribute name="Scheme">IIMProperty</xsl:attribute>
							<xsl:attribute name="Value"><xsl:value-of select="@value"/></xsl:attribute>
						</xsl:element>
					</xsl:if>
				</xsl:for-each>
			</xsl:element>
		</xsl:if>
	</xsl:template>
	<xsl:template name="absnote">
		<xsl:element name="TopicSet" namespace="">
			<xsl:attribute name="Duid"><xsl:text>nitfroletypes</xsl:text></xsl:attribute>
			<xsl:attribute name="FormalName"><xsl:text>Role</xsl:text></xsl:attribute>
			<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
			<xsl:element name="TopicSetRef" namespace="">
				<xsl:attribute name="TopicSet"><xsl:text>urn:newsml:iptc.org:20001006:topicset.iptc-role:1</xsl:text></xsl:attribute>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>nitfrole1</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>Role</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
					<xsl:text>Abstract</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Abstract of NITF content</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>nitfrole2</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>Role</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
					<xsl:text>Note</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Note from NITF content</xsl:text>
				</xsl:element>
			</xsl:element>
			<xsl:element name="Topic" namespace="">
				<xsl:attribute name="Duid"><xsl:text>nitfrole3</xsl:text></xsl:attribute>
				<xsl:element name="TopicType" namespace="">
					<xsl:attribute name="FormalName"><xsl:text>Role</xsl:text></xsl:attribute>
					<xsl:attribute name="Scheme">IptcTopicType</xsl:attribute>
				</xsl:element>
				<xsl:element name="FormalName" namespace="">
					<xsl:attribute name="Scheme">IptcRole</xsl:attribute>
					<xsl:text>Story</xsl:text>
				</xsl:element>
				<xsl:element name="Description" namespace="">
					<xsl:attribute name="xml:lang">en-GB</xsl:attribute>
					<xsl:text>Main NITF content</xsl:text>
				</xsl:element>
			</xsl:element>
		</xsl:element>
	</xsl:template>
</xsl:stylesheet>
